@@ -1,19 +1,19 @@
 # SPDX-License-Identifier: MIT
 # Copyright (c) 2022 MBition GmbH
-
-
 from typing import Union
 
 from ..odxtypes import DataType
 
 from .compumethodbase import CompuMethod
 
-
 class IdenticalCompuMethod(CompuMethod):
     def __init__(self,
+                 *,
                  internal_type: Union[DataType, str],
                  physical_type: Union[DataType, str]):
-        super().__init__(internal_type, physical_type, "IDENTICAL")
+        super().__init__(internal_type=internal_type,
+                         physical_type=physical_type,
+                         category="IDENTICAL")
 
     def convert_physical_to_internal(self, physical_value):
         return physical_value
