@@ -181,11 +181,11 @@ class DiagService:
         return self._request
 
     @property
-    def free_parameters(self) -> Optional[List[Union[Parameter, "EndOfPduField"]]]: # type: ignore
+    def free_parameters(self) -> List[Union[Parameter, "EndOfPduField"]]: # type: ignore
         """Return the list of parameters which can be freely specified by
         the user when encoding the service's request.
         """
-        return self.request.free_parameters if self.request is not None else None
+        return self.request.free_parameters if self.request is not None else []
 
     def print_free_parameters_info(self) -> None:
         """Return a human readable description of the service's
