@@ -1,6 +1,5 @@
 # SPDX-License-Identifier: MIT
 # Copyright (c) 2022 MBition GmbH
-
 import math
 from typing import TYPE_CHECKING, Any, Optional, List, Dict, Iterable, ByteString, OrderedDict, Tuple, Union
 import warnings
@@ -12,6 +11,7 @@ from .dataobjectproperty import DataObjectProperty, DopBase
 from .decodestate import DecodeState, ParameterValuePair
 from .encodestate import EncodeState
 from .exceptions import DecodeError, EncodeError, OdxWarning
+from .odxtypes import odxstr_to_bool
 from .globals import logger
 from .nameditemlist import NamedItemList
 from .parameters import (
@@ -34,26 +34,19 @@ ParameterDict = Dict[str, Union[Parameter, "ParameterDict"]]
 
 class BasicStructure(DopBase):
     def __init__(self,
-                 odx_id,
-                 short_name,
+                 *,
                  parameters: Iterable[Union[Parameter, "EndOfPduField"]],
-                 long_name=None,
-                 byte_size=None,
-                 description=None,
-                 sdgs=[]):
-        super().__init__(odx_id,
-                         short_name,
-                         long_name=long_name,
-                         description=description,
-                         sdgs=sdgs)
-        self.parameters : NamedItemList[Union[Parameter, "EndOfPduField"]] = NamedItemList(short_name_as_id, parameters)
-        self._byte_size = byte_size
+                 byte_size: Optional[int],
+                 **kwargs):
+        super().__init__(**kwargs)
+        self.parameters: NamedItemList[Union[Parameter, "EndOfPduField"]] = NamedItemList(short_name_as_id, parameters)
+        self.byte_size = byte_size
 
     @property
     def bit_length(self):
         # Explicit size was specified
-        if self._byte_size:
-            return 8 * self._byte_size
+        if self.byte_size:
+            return 8 * self.byte_size
 
         if all(p.bit_length is not None for p in self.parameters):
             offset = 0
@@ -167,9 +160,9 @@ class BasicStructure(DopBase):
                 # Undo length_keys changes
                 encode_state.length_keys.pop(param.odx_id)
 
-        if self._byte_size is not None and len(coded_rpc) < self._byte_size:
+        if self.byte_size is not None and len(coded_rpc) < self.byte_size:
             # Padding bytes needed
-            coded_rpc = coded_rpc.ljust(self._byte_size, b'\0')
+            coded_rpc = coded_rpc.ljust(self.byte_size, b'\0')
 
         for (param, encode_state) in length_encodings:
             # Same as previous, but all bytes as 0.
@@ -193,9 +186,9 @@ class BasicStructure(DopBase):
             self,
             coded_rpc: bytearray):
 
-        if self._byte_size is not None:
+        if self.byte_size is not None:
             # We definitely broke something if we didn't respect the explicit byte_size
-            assert len(coded_rpc) == self._byte_size, self._get_encode_error_str('was', coded_rpc, self._byte_size * 8)
+            assert len(coded_rpc) == self.byte_size, self._get_encode_error_str('was', coded_rpc, self.byte_size * 8)
             # No need to check further
             return
 
@@ -329,12 +322,7 @@ class BasicStructure(DopBase):
         super()._resolve_references(odxlinks)
 
         for p in self.parameters:
-            if isinstance(p, ParameterWithDOP):
-                p.resolve_references(parent_dl, odxlinks)
-            elif isinstance(p, TableKeyParameter):
-                p.resolve_references(parent_dl, odxlinks)
-            else:
-                p._resolve_references(odxlinks)
+            p._resolve_references(parent_dl, odxlinks)
 
     def __message_format_lines(self, allow_unknown_lengths: bool = False) \
             -> List[str]:
@@ -401,6 +389,10 @@ class BasicStructure(DopBase):
                         if hasattr(dop, 'diag_coded_type'):
                             dct = dop.diag_coded_type
 
+                    bit_length = None
+                    if hasattr(params[param_idx], "bit_length"):
+                        bit_length = params[param_idx].bit_length
+
                     if dct is not None and dct.dct_type == 'MIN-MAX-LENGTH-TYPE':
                         name = params[param_idx].short_name + " ("
                         if dct.termination == "END-OF-PDU":
@@ -417,7 +409,7 @@ class BasicStructure(DopBase):
 
                         break
 
-                    elif not params[param_idx].bit_length and not allow_unknown_lengths:
+                    elif not bit_length and not allow_unknown_lengths:
                         # The bit length is not set for the current
                         # parameter, i.e. it was either not specified
                         # or the parameter is of variable length and
@@ -426,10 +418,10 @@ class BasicStructure(DopBase):
                         error = True
                         break
                     else:
-                        stop_bit += params[param_idx].bit_length or (
-                            allow_unknown_lengths and 8)
+                        bit_length = 0 if bit_length is None else bit_length
+                        stop_bit += bit_length or (allow_unknown_lengths and 8)
                         name = params[param_idx].short_name + \
-                            f" ({params[param_idx].bit_length or 'Unknown'} bits)"
+                            f" ({bit_length or 'Unknown'} bits)"
                         next_line += "| " + name
 
                     param_idx += 1
@@ -491,25 +483,11 @@ class BasicStructure(DopBase):
 
 class Structure(BasicStructure):
     def __init__(self,
-                 odx_id,
-                 short_name,
-                 parameters,
-                 long_name=None,
-                 byte_size=None,
-                 description=None,
-                 sdgs=[]):
-        super().__init__(odx_id,
-                         short_name,
-                         parameters,
-                         long_name=long_name,
-                         byte_size=byte_size,
-                         description=description,
-                         sdgs=sdgs)
-
-        self.parameters = parameters
+                 **kwargs):
+        super().__init__(**kwargs)
 
     def __repr__(self) -> str:
-        return f"Structure('{self.short_name}', byte_size={self._byte_size})"
+        return f"Structure('{self.short_name}', byte_size={self.byte_size})"
 
     def __str__(self) -> str:
         params = "[\n" + "\n".join([" " + str(p).replace("\n", "\n ")
@@ -517,24 +495,14 @@ class Structure(BasicStructure):
 
         return \
             f"Structure '{self.short_name}': " + \
-            f"Byte size={self._byte_size}, " + \
+            f"Byte size={self.byte_size}, " + \
             f"Parameters={params}"
 
 
 class Request(BasicStructure):
     def __init__(self,
-                 odx_id,
-                 short_name,
-                 parameters,
-                 long_name=None,
-                 description=None,
-                 sdgs=[]):
-        super().__init__(odx_id,
-                         short_name,
-                         parameters,
-                         long_name=long_name,
-                         description=description,
-                         sdgs=sdgs)
+                 **kwargs):
+        super().__init__(**kwargs)
 
     def __repr__(self) -> str:
         return f"Request('{self.short_name}')"
@@ -545,20 +513,12 @@ class Request(BasicStructure):
 
 class Response(BasicStructure):
     def __init__(self,
-                 odx_id,
-                 short_name,
-                 parameters,
-                 long_name=None,
-                 response_type=None,
-                 description=None,
-                 sdgs=[]):
-        super().__init__(odx_id,
-                         short_name,
-                         parameters,
-                         long_name=long_name,
-                         description=description,
-                         sdgs=sdgs)
-        self.response_type = "POS-RESPONSE" if response_type == "POS-RESPONSE" else "NEG-RESPONSE"
+                 *,
+                 response_type: str, # "POS-RESPONSE" or "NEG-RESPONSE"
+                 **kwargs):
+        super().__init__(**kwargs)
+
+        self.response_type = response_type
 
     def encode(self, coded_request: Optional[ByteString] = None, **params) -> ByteString:
         logger.info(f"Compose response message to the request {coded_request}")
@@ -598,33 +558,39 @@ def create_any_structure_from_et(et_element,
     res: Union[Structure, Request, Response, None]
     if et_element.tag == "REQUEST":
         res = Request(
-            odx_id,
-            short_name,
-            parameters=parameters,
+            odx_id=odx_id,
+            short_name=short_name,
             long_name=long_name,
             description=description,
+            is_visible_raw=None,
+            parameters=parameters,
+            byte_size=None,
             sdgs=sdgs,
         )
     elif et_element.tag in ["POS-RESPONSE", "NEG-RESPONSE"]:
         res = Response(
-            odx_id,
-            short_name,
+            odx_id=odx_id,
+            short_name=short_name,
             response_type=et_element.tag,
-            parameters=parameters,
             long_name=long_name,
             description=description,
+            is_visible_raw=None,
+            parameters=parameters,
+            byte_size=None,
             sdgs=sdgs,
         )
     elif et_element.tag == "STRUCTURE":
         byte_size_text = et_element.findtext("BYTE-SIZE")
         byte_size = int(byte_size_text) if byte_size_text is not None else None
+        is_visible_raw = odxstr_to_bool(et_element.get("IS-VISIBLE"))
         res = Structure(
-            odx_id,
-            short_name,
-            parameters=parameters,
-            byte_size=byte_size,
+            odx_id=odx_id,
+            short_name=short_name,
             long_name=long_name,
             description=description,
+            is_visible_raw=is_visible_raw,
+            parameters=parameters,
+            byte_size=byte_size,
             sdgs=sdgs,
         )
     else:
